insert into member (id,loginid, name, passwd) values (0, 'root', 'root', 'root');
insert into rolemember (roleid, memberid) values (0, 0);
insert into daosequence values('rhtym role id', 1);
insert into daosequence values('rhtym member id', 1);
insert into daosequence values('rhtym schedule id', 1);
insert into daosequence values('rhtym todoworker id', 1);
insert into daosequence values('rhtym todotree id', 1);
insert into daosequence values('rhtym addresscategory id', 1);
insert into daosequence values('rhtym addressbook id', 1);
insert into daosequence values('rhtym WindowPos id', 1);
insert into daosequence values('rhtym board id', 1);
insert into daosequence values('rhtym boardtree id', 1);
insert into daosequence values('rhtym RhythmTree id', 1);
insert into daosequence values('rhtym AssignPermission id', 1);
insert into daosequence values('rhythm com.kickmogu.rhythm.core.MailSetting id', 1);
insert into daosequence values('rhtym todo id', 1);
insert into daosequence values('rhtym timecard id', 1);
